﻿$ErrorActionPreference = 'Stop';

$packageName= 'legitest'
$toolsDir   = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$url        = 'http://download.pragmaticworks.com/release/2016.4/LegiTest_2016.4.5.1103.vsix'

$packageArgs = @{
  packageName   = $packageName
  unzipLocation = $toolsDir
  fileType      = "MSU"
  url           = $url

  silentArgs    = "/qn /norestart /l*v `"$env:TEMP\chocolatey\$($packageName)\$($packageName).MsiInstall.log`""
  validExitCodes= @(0, 3010, 1641)

  softwareName  = "legitest*"
  checksum = '06AC9D0D92E96DBB2D168DE4E8A79B116535F32FF51BAF40A5CFB3A02410F2FD'
  checksumType = 'sha256'
  checksum64 = 'MDZBQzlEMEQ5MkU5NkRCQjJEMTY4REU0RThBNzlCMTE2NTM1RjMyRkY1MUJBRjQwQTVDRkIzQTAyNDEwRjJGRA=='
  checksumType64 = 'sha256'
}

Function Test-VsRegistry($registryPath, $registryProperty)
{
    $result = Get-ItemProperty $registryPath $registryProperty -ErrorAction SilentlyContinue
    
    if (($result -ne $null) -and ($result.InstallDir -ne $null) -and ($result.InstallDir.Length -gt 0))
    {
        return $true
    }

    return $false
}

$isInstallLegiTest = $false
$vs2012 = $false
$vs2013 = $false
$vs2015 = $false

if ([IntPtr]::size -eq 8)
{
    $vs2012 = Test-VsRegistry("HKLM:\Software\WOW6432NODE\Microsoft\VisualStudio\11.0", "InstallDir")
    $vs2013 = Test-VsRegistry("HKLM:\Software\WOW6432NODE\Microsoft\VisualStudio\12.0", "InstallDir")
	$vs2015 = Test-VsRegistry("HKLM:\Software\WOW6432NODE\Microsoft\VisualStudio\14.0", "InstallDir")

    if (($vs2012 -eq $false) -and 
        ($vs2013 -eq $false) -and
		($vs2015 -eq $false))
    {
        $isInstallLegiTest = $false
    }
    else
    {
        $isInstallLegiTest = $true
    }
}
else
{
    $vs2012 = Test-VsRegistry("HKLM:\Software\Microsoft\VisualStudio\11.0", "InstallDir")
    $vs2013 = Test-VsRegistry("HKLM:\Software\Microsoft\VisualStudio\12.0", "InstallDir")
	$vs2015 = Test-VsRegistry("HKLM:\Software\Microsoft\VisualStudio\14.0", "InstallDir")

    if (($vs2012 -eq $false) -and 
        ($vs2013 -eq $false) -and
		($vs2015 -eq $false))
    {
        $isInstallLegiTest = $false
    }
    else
    {
        $isInstallLegiTest = $true
    }
}

if ($isInstallLegiTest -eq $true)
{
    Install-ChocolateyVsixPackage $packageName $url
}
else
{
    throw "LegiTest requires Visual Studio 2012, 2013, 2015."
}
